=========
Changelog
=========

All notable changes to `SandPaper <https://github.com/stephen-bunn/sandpaper/>`_ will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/en/1.0.0/>`_ and this project adheres to `Semantic Versioning <http://semver.org/spec/v2.0.0.html>`_.


`0.0.1`_ (*unreleased*)
-----------------------
* added the project's base structure (wish i could include change logs for prior structure updates)
* fixed the project's base structure for PY2 compatability
